# WATER_SORT_PUZZLE

"Water Sort Puzzle" is a game where the player must ensure that 
each bottle only contains one colour. This game is a command line interface
game inspired by "Water Sort Puzzle" game on Google Play Store 
(https://play.google.com/store/apps/details?id=com.gma.water.sort.puzzle&hl=en_NZ&gl=US).

# Executable File

The executable file is downloadable at https://github.com/GlobalCreativeCommunityFounder/WATER_SORT_PUZZLE/blob/master/WATER_SORT_PUZZLE/dist/water_sort_puzzle/water_sort_puzzle.exe.

# Source Code

Python code used to create the game application is available in 
https://github.com/GlobalCreativeCommunityFounder/WATER_SORT_PUZZLE/blob/master/WATER_SORT_PUZZLE/water_sort_puzzle.py.

# How to Use the Executable File?

First, open by double clicking the file "water_sort_puzzle.exe". How the executable
file looks like is shown in the image below.

![Executable File](images/Executable%20File.png)

# Getting Started

Once you run the game, you will be asked whether you want to continue playing the game
"Water Sort Puzzle" or not. If you enter 'Y', you will be able to try to sort water bottles
based on water colours. Entering anything else will make you quit the game.

![Getting Started](images/Getting%20Started.png)

# The Game

In the game, your task is to make sure all bottles only contain one or less water colours.
Water can only be poured to empty bottles or bottles which the same water colours at the top.
Below shows how the user is asked for inputs in the game (i.e., inputs for indices of water bottles
to pour to and from).

![The Game](images/The%20Game.png)

A window like in the image above which asks for user input for pouring water will keep on
popping up until all the water bottles are sorted. Once you successfully sort all the water bottles, 
you will be asked whether you want to continue playing the game at the next level or not. To go to the next level,
enter 'Y'. Entering anything else will exit the game.
